package com.andersjbe.springflux.controller;

import com.andersjbe.springflux.model.Person;
import com.andersjbe.springflux.service.PersonService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import reactor.core.publisher.Flux;
import reactor.core.publisher.Mono;

@RestController
@RequestMapping("api/people")
public class PersonController {

    @Autowired
    PersonService service;

    @GetMapping("")
    public Flux<Person> getPeople() {
        return service.findAll();
    }

    @GetMapping("/{id}")
    public Mono<Person> getPersonById(@PathVariable("id") String id) {
        return service.findById(id);
    }

    @PostMapping("")
    public Mono<Person> postPerson(@RequestBody Person person) {
        System.out.println(person);
        return service.create(person);
    }

    @PutMapping("{id}")
    public Mono<Person> putPerson(@PathVariable("id") String id, @RequestBody Person person) throws Exception {
        return service.update(id, person);
    }

    @DeleteMapping("{id}")
    public Mono<Person> deletePerson(@PathVariable("id") String id) throws Exception {
        return  service.delete(id);
    }
}
