package com.andersjbe.springflux.service;

import com.andersjbe.springflux.model.Person;
import com.andersjbe.springflux.repository.PersonRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import reactor.core.publisher.Flux;
import reactor.core.publisher.Mono;

@Service
public class PersonService {

    @Autowired
    PersonRepository repository;

    public Flux<Person> findAll() {
        return repository.findAll();
    }

    public Mono<Person> findById(String id) {
        return repository.findById(id);
    }

    public Mono<Person> create(Person person) {
        return repository.save(person);
    }

    public Mono<Person> update(String id, Person fresh) throws Exception {
        if (!repository.existsPersonById(id)) {
            throw new Exception("Person does not exist!");
        }

        Mono<Person> stale = repository.findById(id);
        return stale.map(person -> {
            if (!person.getName().equals(fresh.getName())) {
                person.setName(fresh.getName());
            }

            repository.save(person);
            return person;
        });
    }

    public Mono<Person> delete(String id) throws Exception {
        if (!repository.existsPersonById(id)) {
            throw new Exception("Person does not exist!");
        }
        return repository.deletePersonById(id);
    }
}
